@@ -15,6 +15,7 @@
 # under the License.
 
 import abc
+import json
 import warnings
 
 import dirq.QueueSimple
@@ -23,6 +24,7 @@ from oslo_log import log
 import six
 
 import caso.messenger
+import caso.record
 from caso import utils
 
 LOG = log.getLogger(__name__)
@@ -41,58 +43,77 @@ CONF = cfg.CONF
 CONF.register_opts(opts, group="ssm")
 
 
-__all__ = ["SsmMessager", "SSMMessengerV02", "SSMMessengerV04"]
+__all__ = ["SsmMessenger", "SSMMessengerV02", "SSMMessengerV04"]
 
 
 @six.add_metaclass(abc.ABCMeta)
 class _SSMBaseMessenger(caso.messenger.BaseMessenger):
-    version = None
-    separator = "%%"
+    compute_version = None
+    ip_version = None
 
     def __init__(self):
         # FIXME(aloga): try except here
         utils.makedirs(CONF.ssm.output_path)
-        self.header = "APEL-cloud-message: v%s" % self.version
+
+    def push_compute_message(self, queue, entries):
+        message = "APEL-cloud-message: v%s\n" % self.compute_version
+        aux = "%%\n".join(entries)
+        message += "%s\n" % aux
+        queue.add(message)
+
+    def push_ip_message(self, queue, entries):
+        message = {
+            "Type": "APEL Public IP message",
+            "Version": self.ip_version,
+            "UsageRecords": entries,
+        }
+        queue.add(json.dumps(message))
 
     def push(self, records):
         if not records:
             return
 
-        entries = []
+        entries_cloud = []
+        entries_ip = []
         for _, record in six.iteritems(records):
-            aux = ""
-            for k, v in six.iteritems(record.as_dict(version=self.version)):
-                if v is not None:
-                    aux += "%s: %s\n" % (k, v)
-            entries.append(aux)
+            if isinstance(record, caso.record.CloudRecord):
+                aux = ""
+                for k, v in six.iteritems(record.as_dict(
+                                          version=self.compute_version)):
+                    if v is not None:
+                        aux += "%s: %s\n" % (k, v)
+                entries_cloud.append(aux)
+            else:
+                entries_ip.append(record.as_dict(version=self.ip_version))
 
         # FIXME(aloga): try except here
         queue = dirq.QueueSimple.QueueSimple(CONF.ssm.output_path)
 
         # Divide message into smaller chunks as per GGUS #143436
         # https://ggus.eu/index.php?mode=ticket_info&ticket_id=143436
-        for i in range(0, len(entries), CONF.ssm.max_size):
-            message = "%s\n" % self.header
+        for i in range(0, len(entries_cloud), CONF.ssm.max_size):
+            entries = entries_cloud[i:i + CONF.ssm.max_size]
+            self.push_compute_message(queue, entries)
 
-            sep = "%s\n" % self.separator
-            message += "%s" % sep.join(entries[i:i + CONF.ssm.max_size])
-
-            queue.add(message)
+        for i in range(0, len(entries_ip), CONF.ssm.max_size):
+            entries = entries_ip[i:i + CONF.ssm.max_size]
+            self.push_ip_message(queue, entries)
 
 
 class SSMMessengerV02(_SSMBaseMessenger):
-    version = "0.2"
+    compute_version = "0.2"
 
 
 class SSMMessengerV04(_SSMBaseMessenger):
-    version = "0.4"
+    compute_version = "0.4"
+    ip_version = "0.2"
 
 
-class SsmMessager(SSMMessengerV02):
+class SsmMessenger(SSMMessengerV02):
     def __init__(self):
         msg = ("Using deprecated caso.messenger.ssm.SsmMessager, "
                "please use caso.messenger.ssm.SSMMessengerV02 if you "
                "wish to continue usinf the 0.2 version of the record, "
                "or refer to the cASO documentation.")
         warnings.warn(msg, DeprecationWarning)
-        super(SsmMessager, self).__init__()
+        super(SsmMessenger, self).__init__()
